helpers/platform_functions library

Functions

contentStyle(BuildContext context, dynamic value, bool enabled) → TextStyle?
This centralizes the style calculations for content, used by almost all widgets in this package
labelStyle(BuildContext context, bool enabled) → TextStyle?
This centralizes the style calculations for field labels, used by almost all widgets in this package
showCupertino(BuildContext? context, bool? showMaterialonIOS, {bool mockIOS = false}) → bool
this centralizes code to determine if we want to display the cupertino version or the material version, since this can be determined by several settings throughout the package