PickerModel class

Constructors

PickerModel(String name, {Object? code, Icon? icon})
const

Properties

code → Object?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Icon?
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited