CardSettingsField class

This is the basic layout of a field in a CardSettings view. Typcially, it will not be used directly.

Inheritance
Implemented types

Constructors

CardSettingsField({String label = 'Label', required Widget content, Icon? icon, IconData? pickerIcon, double? labelWidth, bool contentOnNewLine = false, String? unitLabel, String? errorText, bool visible = true, required TextAlign? labelAlign, required Widget? requiredIndicator, bool enabled = true, required EdgeInsetsGeometry? fieldPadding})

Properties

autovalidateMode → AutovalidateMode
no setteroverride
content → Widget
The widget that is placed in the content region of the field
final
contentAlign → TextAlign
no setteroverride
contentOnNewLine → bool
Place the content below the label rather than next to the label
final
enabled → bool
If false, grays out the field and makes it unresponsive
final
errorText → String?
The text to display if the field fails validation
final
fieldPadding → EdgeInsetsGeometry?
padding to place around the entire field widget
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Icon?
The icon to display to the left of the field content
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String
The text to identify the field to the user
final
labelAlign → TextAlign?
The alignment of the label paret of the field. Default is left.
final
labelWidth → double?
The width of the field label. If provided overrides the global setting.
final
onChanged → Function
no setteroverride
onSaved → Function
no setteroverride
pickerIcon → IconData?
If the field is a picker, this is the icon shown to the right of the content
final
requiredIndicator → Widget?
A widget to show next to the label if the field is required
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showMaterialonIOS → bool
no setteroverride
unitLabel → String?
If provided, displays text to the right of the content.
final
validator → Function
no setteroverride
visible → bool
If false hides the widget on the card setting panel
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited