CardSettings class

This is the card wrapper that all the field controls are placed into

Inheritance

Constructors

CardSettings({Key? key, TextAlign? labelAlign, double? labelWidth, double? labelPadding, String? labelSuffix, TextAlign contentAlign = TextAlign.left, EdgeInsetsGeometry padding = const EdgeInsets.all(0.0), EdgeInsetsGeometry margin = const EdgeInsets.all(8.0), double? cardElevation, List<CardSettingsSection> children = const <CardSettingsSection>[], bool showMaterialonIOS = false, bool shrinkWrap = false, bool cardless = false, Divider? divider, bool scrollable = true, EdgeInsetsGeometry? fieldPadding})
CardSettings.sectioned({Key? key, TextAlign? labelAlign, double? labelWidth, double? labelPadding, String? labelSuffix, TextAlign contentAlign = TextAlign.left, EdgeInsetsGeometry padding = const EdgeInsets.all(0.0), EdgeInsetsGeometry margin = const EdgeInsets.fromLTRB(8, 8, 8, 0.0), double? cardElevation, List<CardSettingsSection> children = const <CardSettingsSection>[], bool showMaterialonIOS = false, bool shrinkWrap = true, bool cardless = false, Divider? divider, bool scrollable = true, EdgeInsetsGeometry? fieldPadding})
constructor that wraps each section in it's own card

Properties

cardElevation → double?
final
cardless → bool
final
child → Widget
The widget below this widget in the tree.
finalinherited
contentAlign → TextAlign
final
divider → Divider?
final
fieldPadding → EdgeInsetsGeometry?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelAlign → TextAlign?
final
labelPadding → double?
final
labelSuffix → String?
final
labelWidth → double?
final
margin → EdgeInsetsGeometry
final
padding → EdgeInsetsGeometry
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollable → bool
final
showMaterialonIOS → bool
final
shrinkWrap → bool
final

Methods

createElement() → InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant CardSettings old) → bool
notify child widgets if a setting changes on the overall wrapper
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → CardSettings?