CardSettingsDouble class

This is a phone number field. It's designed for US numbers

Inheritance
Implemented types

Constructors

CardSettingsDouble({Key? key, String label = 'Label', double? labelWidth, TextAlign? labelAlign, String? hintText, String? prefixText, TextAlign? contentAlign, double? initialValue, bool contentOnNewLine = false, int maxLength = 10, int decimalDigits = 2, Icon? icon, Widget? requiredIndicator, String? unitLabel, bool visible = true, bool enabled = true, bool autofocus = false, bool obscureText = false, AutovalidateMode autovalidateMode = AutovalidateMode.onUserInteraction, FormFieldValidator<double>? validator, FormFieldSetter<double>? onSaved, ValueChanged<double?>? onChanged, TextEditingController? controller, FocusNode? focusNode, TextInputAction? inputAction, FocusNode? inputActionNode, TextInputType? keyboardType, TextStyle? style, MaxLengthEnforcement? maxLengthEnforcement = MaxLengthEnforcement.enforced, ValueChanged<String>? onFieldSubmitted, List<TextInputFormatter>? inputFormatters, bool? showMaterialonIOS, Locale? locale, EdgeInsetsGeometry? fieldPadding})

Properties

autofocus → bool
Allows flutter to advance to this field
final
autovalidateMode → AutovalidateMode
used to configure the autovalidation of this field
final
contentAlign → TextAlign?
controls how the widget in the content area of the field is aligned
final
contentOnNewLine → bool
Put the content below the label
final
controller → TextEditingController?
You can provide a custom text controller here
final
decimalDigits → int
the number of digits allowed after the decimal
final
enabled → bool
If false, grays out the field and makes it unresponsive
final
fieldPadding → EdgeInsetsGeometry?
provides padding to wrap the entire field
final
focusNode → FocusNode?
the order for this node to receive focus
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
text to display to guide the user on what to enter
final
icon → Icon?
The icon to display to the left of the field content
final
initialValue → double?
The initial value of the content
final
inputAction → TextInputAction?
final
inputActionNode → FocusNode?
final
inputFormatters → List<TextInputFormatter>?
input formatters to enforce entry
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
the type of keyboard to show
final
label → String
The text to identify the field to the user
final
labelAlign → TextAlign?
The alignment of the label paret of the field. Default is left.
final
labelWidth → double?
The width of the field label. If provided overrides the global setting.
final
locale → Locale?
the localization region to use
final
maxLength → int
number of digits for the value
final
maxLengthEnforcement → MaxLengthEnforcement?
the max length of the number in characters
final
obscureText → bool
final
onChanged → ValueChanged<double?>?
This fires when the value is changed
final
onFieldSubmitted → ValueChanged<String>?
This fires when the form is submitted
final
onSaved → ValueChanged<double?>?
This fires when the form is saved
final
prefixText → String?
Text to show before the content area
final
requiredIndicator → Widget?
A widget to show next to the label if the field is required
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showMaterialonIOS → bool?
Force the widget to use Material style on an iOS device
final
style → TextStyle?
The style for the label
final
unitLabel → String?
if provided, show text after the value
final
validator → FormFieldValidator<double>?
The function to call to validate the content
final
visible → bool
If false hides the widget on the card setting panel
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited