CardSettingsInt class

This is a password field. It obscures the entered text.

Inheritance
Implemented types

Constructors

CardSettingsInt({Key? key, String label = 'Label', TextAlign? labelAlign, double? labelWidth, TextAlign? contentAlign, String? hintText, int initialValue = 0, Icon? icon, Widget? requiredIndicator, String? unitLabel, int maxLength = 10, bool visible = true, bool enabled = true, bool autofocus = false, bool obscureText = false, bool autocorrect = false, AutovalidateMode autovalidateMode = AutovalidateMode.onUserInteraction, FormFieldValidator<int>? validator, FormFieldSetter<int>? onSaved, ValueChanged<int?>? onChanged, TextEditingController? controller, FocusNode? focusNode, TextInputAction? inputAction, FocusNode? inputActionNode, TextInputType? keyboardType, TextStyle? style, MaxLengthEnforcement? maxLengthEnforcement = MaxLengthEnforcement.enforced, ValueChanged<String>? onFieldSubmitted, List<TextInputFormatter>? inputFormatters, bool? showMaterialonIOS, EdgeInsetsGeometry? fieldPadding})

Properties

autocorrect → bool
finalinherited
autofocus → bool
finalinherited
autovalidateMode → AutovalidateMode
Used to enable/disable this form field auto validation and update its error text.
finalinherited
builder → FormFieldBuilder<String>
Function that returns the widget representing this form field.
finalinherited
contentAlign → TextAlign?
finalinherited
contentOnNewLine → bool
finalinherited
contentPadding → EdgeInsetsGeometry
finalinherited
controller → TextEditingController?
finalinherited
enabled → bool
Whether the form is able to receive user input.
finalinherited
errorBuilder → FormFieldErrorBuilder?
Function that returns the widget representing the error to display.
finalinherited
fieldPadding → EdgeInsetsGeometry?
finalinherited
focusNode → FocusNode?
finalinherited
forceErrorText → String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
finalinherited
icon → Icon?
finalinherited
initialValue → String?
An optional value to initialize the form field to, or null otherwise.
finalinherited
inputAction → TextInputAction?
finalinherited
inputActionNode → FocusNode?
finalinherited
inputFormatters → List<TextInputFormatter>?
finalinherited
inputMask → String?
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType
finalinherited
label → String
finalinherited
labelAlign → TextAlign?
finalinherited
labelWidth → double?
finalinherited
maxLength → int
finalinherited
maxLengthEnforcement → MaxLengthEnforcement?
finalinherited
numberOfLines → int
finalinherited
obscureText → bool
finalinherited
onChanged → ValueChanged<String>?
finalinherited
onFieldSubmitted → ValueChanged<String>?
finalinherited
onReset → VoidCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
finalinherited
onSaved → FormFieldSetter<String>?
Since the CupertinoTextField does not support onSaved, please use onChanged or onFieldSubmitted instead
finalinherited
prefixText → String?
finalinherited
requiredIndicator → Widget?
finalinherited
restorationId → String?
Restoration ID to save and restore the state of the form field.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showClearButtonIOS → OverlayVisibilityMode
finalinherited
showCounter → bool
finalinherited
showMaterialonIOS → bool?
finalinherited
style → TextStyle?
finalinherited
textCapitalization → TextCapitalization
finalinherited
unitLabel → String?
finalinherited
validator → FormFieldValidator<String>?
In material mode this shows the validation text under the field In cupertino mode, it shows a red Border around the CupertinoTextField
finalinherited
visible → bool
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CardSettingsTextState
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited