CardSettingsSlider class

This is a field that allows a boolean to be set via a switch widget.

Inheritance
Implemented types

Constructors

CardSettingsSlider({Key? key, bool autovalidate = false, AutovalidateMode autovalidateMode = AutovalidateMode.onUserInteraction, FormFieldSetter<double>? onSaved, FormFieldValidator<double>? validator, double initialValue = 0.0, bool enabled = true, bool visible = true, String label = 'Label', Widget? requiredIndicator, TextAlign? labelAlign, double? labelWidth, Icon? icon, TextAlign? contentAlign, ValueChanged<double>? onChanged, ValueChanged<double>? onChangedStart, ValueChanged<double>? onChangedEnd, double? min, double? max, int? divisions, bool? showMaterialonIOS, EdgeInsetsGeometry? fieldPadding})

Properties

autovalidateMode → AutovalidateMode
Used to enable/disable this form field auto validation and update its error text.
finalinherited
builder → FormFieldBuilder<double>
Function that returns the widget representing this form field.
finalinherited
contentAlign → TextAlign?
controls how the widget in the content area of the field is aligned
final
divisions → int?
how many divisions to have between min and max
final
enabled → bool
If false the field is grayed out and unresponsive
final
errorBuilder → FormFieldErrorBuilder?
Function that returns the widget representing the error to display.
finalinherited
fieldPadding → EdgeInsetsGeometry?
provides padding to wrap the entire field
final
forceErrorText → String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → Icon?
The icon to display to the left of the field content
final
initialValue → double?
An optional value to initialize the form field to, or null otherwise.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String
The text to identify the field to the user
final
labelAlign → TextAlign?
The alignment of the label paret of the field. Default is left.
final
labelWidth → double?
The width of the field label. If provided overrides the global setting.
final
max → double?
The value at the maximum position
final
min → double?
The value at the minimum position
final
onChanged → ValueChanged<double>?
final
onChangedEnd → ValueChanged<double>?
final
onChangedStart → ValueChanged<double>?
final
onReset → VoidCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
finalinherited
onSaved → FormFieldSetter<double>?
An optional method to call with the final value when the form is saved via FormState.save.
finalinherited
requiredIndicator → Widget?
A widget to show next to the label if the field is required
final
restorationId → String?
Restoration ID to save and restore the state of the form field.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showMaterialonIOS → bool?
Force the widget to use Material style on an iOS device
final
validator → FormFieldValidator<double>?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
finalinherited
visible → bool
If false hides the widget on the card setting panel
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CardSettingsSliderState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited