CardSettingsPhone class

This is a phone number field. It's designed for US numbers

Inheritance
Implemented types

Constructors

CardSettingsPhone({Key? key, String label = 'Phone', double? labelWidth, TextAlign? labelAlign, String? hintText, String? prefixText, TextAlign? contentAlign, int? initialValue, bool contentOnNewLine = false, int maxLength = 20, Icon? icon, Widget? requiredIndicator, bool visible = true, bool enabled = true, bool autofocus = false, bool obscureText = false, bool autocorrect = false, AutovalidateMode autovalidateMode = AutovalidateMode.onUserInteraction, FormFieldValidator<int>? validator, FormFieldSetter<int>? onSaved, ValueChanged<int?>? onChanged, TextEditingController? controller, FocusNode? focusNode, TextInputAction? inputAction, FocusNode? inputActionNode, TextInputType? keyboardType, TextStyle? style, MaxLengthEnforcement? maxLengthEnforcement = MaxLengthEnforcement.enforced, ValueChanged<String>? onFieldSubmitted, List<TextInputFormatter>? inputFormatters, bool? showMaterialonIOS, EdgeInsetsGeometry? fieldPadding})

Properties

autocorrect → bool
final
autofocus → bool
final
autovalidateMode → AutovalidateMode
final
contentAlign → TextAlign?
final
contentOnNewLine → bool
final
controller → TextEditingController?
final
enabled → bool
final
fieldPadding → EdgeInsetsGeometry?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
final
icon → Icon?
final
initialValue → int?
final
inputAction → TextInputAction?
final
inputActionNode → FocusNode?
final
inputFormatters → List<TextInputFormatter>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
final
label → String
final
labelAlign → TextAlign?
final
labelWidth → double?
final
maxLength → int
final
maxLengthEnforcement → MaxLengthEnforcement?
final
obscureText → bool
final
onChanged → ValueChanged<int?>?
final
onFieldSubmitted → ValueChanged<String>?
final
onSaved → ValueChanged<int?>?
final
prefixText → String?
final
requiredIndicator → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showMaterialonIOS → bool?
final
style → TextStyle?
final
validator → FormFieldValidator<int>?
final
visible → bool
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited