CardSettingsText class

This is a standard one line text entry It's based on the TextFormField widget.

Inheritance
Implemented types
Implementers

Constructors

CardSettingsText({Key? key, String? initialValue, bool autovalidate = false, AutovalidateMode autovalidateMode = AutovalidateMode.onUserInteraction, bool enabled = true, FormFieldSetter<String>? onSaved, FormFieldValidator<String>? validator, ValueChanged<String>? onChanged, TextEditingController? controller, TextCapitalization textCapitalization = TextCapitalization.none, TextInputType keyboardType = TextInputType.text, MaxLengthEnforcement? maxLengthEnforcement = MaxLengthEnforcement.enforced, String? inputMask, List<TextInputFormatter>? inputFormatters, ValueChanged<String>? onFieldSubmitted, TextStyle? style, FocusNode? focusNode, TextInputAction? inputAction, FocusNode? inputActionNode, String label = 'Label', bool contentOnNewLine = false, int maxLength = 20, int numberOfLines = 1, bool showCounter = false, bool visible = true, bool autocorrect = true, bool obscureText = false, bool autofocus = false, TextAlign? contentAlign, String? hintText, Icon? icon, TextAlign? labelAlign, double? labelWidth, String? prefixText, Widget? requiredIndicator, String? unitLabel, bool? showMaterialonIOS, OverlayVisibilityMode showClearButtonIOS = OverlayVisibilityMode.never, EdgeInsetsGeometry? fieldPadding, EdgeInsetsGeometry contentPadding = const EdgeInsets.all(0.0)})

Properties

autocorrect → bool
final
autofocus → bool
final
autovalidateMode → AutovalidateMode
Used to enable/disable this form field auto validation and update its error text.
finalinherited
builder → FormFieldBuilder<String>
Function that returns the widget representing this form field.
finalinherited
contentAlign → TextAlign?
final
contentOnNewLine → bool
final
contentPadding → EdgeInsetsGeometry
final
controller → TextEditingController?
final
enabled → bool
Whether the form is able to receive user input.
final
errorBuilder → FormFieldErrorBuilder?
Function that returns the widget representing the error to display.
finalinherited
fieldPadding → EdgeInsetsGeometry?
final
focusNode → FocusNode?
final
forceErrorText → String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
final
icon → Icon?
final
initialValue → String?
An optional value to initialize the form field to, or null otherwise.
finalinherited
inputAction → TextInputAction?
final
inputActionNode → FocusNode?
final
inputFormatters → List<TextInputFormatter>?
final
inputMask → String?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType
final
label → String
final
labelAlign → TextAlign?
final
labelWidth → double?
final
maxLength → int
final
maxLengthEnforcement → MaxLengthEnforcement?
final
numberOfLines → int
final
obscureText → bool
final
onChanged → ValueChanged<String>?
final
onFieldSubmitted → ValueChanged<String>?
final
onReset → VoidCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
finalinherited
onSaved → FormFieldSetter<String>?
Since the CupertinoTextField does not support onSaved, please use onChanged or onFieldSubmitted instead
final
prefixText → String?
final
requiredIndicator → Widget?
final
restorationId → String?
Restoration ID to save and restore the state of the form field.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showClearButtonIOS → OverlayVisibilityMode
final
showCounter → bool
final
showMaterialonIOS → bool?
final
style → TextStyle?
final
textCapitalization → TextCapitalization
final
unitLabel → String?
final
validator → FormFieldValidator<String>?
In material mode this shows the validation text under the field In cupertino mode, it shows a red Border around the CupertinoTextField
final
visible → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CardSettingsTextState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited